============
Contributing
============

Contributions are welcome, and they are greatly appreciated! Every
little bit helps, and credit will always be given.

You can contribute in many ways:

Types of Contributions
----------------------

Report Bugs
~~~~~~~~~~~

Report bugs at https://github.com/titusjan/argos/issues.

If you are reporting a bug, please include:

* Your operating system name and version.
* Any details about your local setup that might be helpful in troubleshooting.
* Detailed steps to reproduce the bug.

Fix Bugs
~~~~~~~~

Look through the GitHub issues for bugs. Anything tagged with "bug"
is open to whoever wants to implement it.

Implement Features
~~~~~~~~~~~~~~~~~~

Look through the GitHub issues for features. Anything tagged with "feature"
is open to whoever wants to implement it.

Write Documentation
~~~~~~~~~~~~~~~~~~~

Argos could always use more documentation, whether as part of the
official Argos docs, in docstrings, or even on the web in blog posts,
articles, and such.

Submit Feedback
~~~~~~~~~~~~~~~

The best way to send feedback is to file an issue at https://github.com/titusjan/argos/issues.

If you are proposing a feature:

* Explain in detail how it would work.
* Keep the scope as narrow as possible, to make it easier to implement.
* Remember that this is a volunteer-driven project and that there is not guarantee that your
  feature will be implemented.


Get Started!
------------

Ready to contribute? Here's how to set up `argos` for local development.

0. Keep in mind that there is no guarantee that your pull request will be accepted. When in doubt,
   send me an email or open an issue to discuss it before spending a lot of time on it.
1. Fork the `argos` repo on GitHub.
2. Clone your fork locally::

    $ git clone git@github.com:your_name_here/argos.git

3. Install your local copy into a virtualenv. Assuming you have virtualenvwrapper installed, this
   is how you set up your fork for local development::

    $ mkvirtualenv argos
    $ cd argos/
    $ python setup.py develop

4. Create a branch for local development::

    $ git checkout -b name-of-your-bugfix-or-feature

   Now you can make your changes locally.

5. Commit your changes and push your branch to GitHub::

    $ git add .
    $ git commit -m "Your detailed description of your changes."
    $ git push origin name-of-your-bugfix-or-feature

6. Submit a pull request through the GitHub website.
